@@ -598,7 +598,7 @@ update_array_async_thread_func (GTask        *task,
 	g_ptr_array_set_size (errors, g_strv_length (updates));
 
 	/* Fast path, perform everything as a single update */
-	concatenated = g_strjoinv (" ", updates);
+	concatenated = g_strjoinv ("; ", updates);
 	tracker_sparql_connection_update (source_object, concatenated,
 	                                  g_task_get_priority (task),
 	                                  cancellable, &error);
@@ -611,12 +611,12 @@ update_array_async_thread_func (GTask        *task,
 
 	/* Slow path, perform updates one by one */
 	for (i = 0; updates[i]; i++) {
-		GError *err = NULL;
+		GError **err = NULL;
 
-		err = g_ptr_array_index (errors, i);
+		err = (GError **) &g_ptr_array_index (errors, i);
 		tracker_sparql_connection_update (source_object, updates[i],
 		                                  g_task_get_priority (task),
-		                                  cancellable, &err);
+		                                  cancellable, err);
 	}
 
 	g_task_return_pointer (task, errors,
